magneticalc.SidebarRight.SidebarRight

# ``magneticalc`.`SidebarRight`.`SidebarRight``

class documentation

`class SidebarRight(QScrollArea):`

Constructor: `SidebarRight(gui)`

View In Hierarchy

SidebarRight class.

Method | `__init__` | Populates the right sidebar.
Class Variable | `MaximumWidth` | Undocumented
Class Variable | `VerticalSpacing` | Undocumented
Instance Variable | `display_widget` | Undocumented
Instance Variable | `field_widget` | Undocumented
Instance Variable | `gui` | Undocumented
Instance Variable | `metric_widget` | Undocumented
Instance Variable | `parameters_widget` | Undocumented
Instance Variable | `perspective_widget` | Undocumented

def __init__(self, gui: `GUI`):

Populates the right sidebar.

Parameters
gui: `GUI` | GUI

MaximumWidth: `int` =

Undocumented

VerticalSpacing: `int` =

Undocumented

display_widget =

Undocumented

field_widget =

Undocumented

gui =

Undocumented

metric_widget =

Undocumented

parameters_widget =

Undocumented

perspective_widget =

Undocumented